@@ -8,6 +8,7 @@ import inspect
 import warnings
 import urllib3
 import ssl
+from pprint import pprint
 
 import pyrena.classes as classes
 
@@ -120,9 +121,6 @@ class Arena():
         #set time to re-auth, 1 min before expiry
         self.reauth_utc = int(time.time())+60*60*80
 
-        if self._debug:
-            print(login_data)
-
     def logout(self):
 
         """
@@ -162,7 +160,12 @@ class Arena():
             raise requests.exceptions.SSLError("Unable to establish a secure connection to Arena. Use a different internet connection or use `ssl_verify=False` to allow insecure requests.")
 
         if self._debug:
-            print(f"{method.upper()} {endpoint} - {req.status_code}")
+            print("===PAYLOAD===")
+            print(f"{method.upper()} {endpoint}")
+            pprint(data)
+            print("===RESPONSE===")
+            print(f"status {req.status_code}")
+            pprint(req.json())
 
         if req.status_code >=400:
             data=req.json()
